@@ -1,4 +1,4 @@
-// Copyright (c) 2021 René Kijewski <crates.io@k6i.de>
+// Copyright (c) 2021-2022 René Kijewski <crates.io@k6i.de>
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 #![no_std]
 #![cfg_attr(feature = "docsrs", feature(doc_cfg))]
 #![forbid(unsafe_code)]
+#![allow(unused_attributes)]
 #![warn(absolute_paths_not_starting_with_crate)]
 #![warn(elided_lifetimes_in_paths)]
 #![warn(explicit_outlives_requirements)]
@@ -37,11 +38,17 @@
 //! [![Crates.io](https://img.shields.io/crates/v/nate)](https://crates.io/crates/nate)
 //! [![License](https://img.shields.io/crates/l/nate?color=informational)](/LICENSES)
 //!
-//! ## **N**ot **a** **T**emplate **E**ngine
+//! ## NaTE — Not a Template Engine
 //!
-//! This is not a template engine, but sugar to implicitly call `write!(…)` like in PHP.
+//! This is *not* a template engine, but sugar to implicitly call `write!(…)` like in PHP.
 //! The only difference is that the output gets XML escaped automatically unless opted-out explicitly.
 //!
+//! Unlike other template engines like
+//! [Askama](https://crates.io/crates/askama), [Handlebars](https://crates.io/crates/handlebars),
+//! [Liquid](https://github.com/cobalt-org/liquid-rust), [Tera](https://crates.io/crates/tera), or
+//! [Tide](https://crates.io/crates/tide), you don't have to learn a new language.
+//! If you know Rust and HTML, you already know how to implement templates with NaTE!
+//!
 //! E.g.
 //!
 //! *   templates/greeting.html:
@@ -76,7 +83,7 @@
 //!     <h1>Hello, &#60;World&#62;!</h1>
 //!     ```
 //!
-//! No new traits are introduced, instead using `#[derive(Nate)]` works by implementing [fmt::Display].
+//! No new traits are needed, instead `#[derive(Nate)]` primarily works by implementing [fmt::Display].
 //! This also makes nesting of NaTE templates possible.
 //!
 //! A more complex example would be:
@@ -132,7 +139,7 @@
 //!
 //! For values in `{{{{{ verbose blocks }}}}}` their debug message is printed verbose as in `"{:#?}"`.
 //!
-//! With `{< include >}` block you can include a template file.
+//! With `{< include >}` blocks you can include a template file.
 //! It then behaves like it was copy-pasted into the current file.
 //! If the path starts with "." or "..", the file is searched relative to the current file.
 //! Otherwise it is search in the project root.
